@@ -3,6 +3,6 @@ import random
 def dice(sides):
     if sides == 10:
         # Of course d10s have to be different.
-        return str(random.randrange(0, 9))
+        return str(random.randrange(0, 10))
     else:
-        return str(random.randrange(1, sides))
\ No newline at end of file
+        return str(random.randrange(1, sides + 1))
\ No newline at end of file
